@@ -8,7 +8,7 @@ from lintian_brush.control import (
 
 def drop_build_essential(control):
     control["Build-Depends"] = drop_dependency(
-        control["Build-Depends"], "build-essential")
+        control.get("Build-Depends", ""), "build-essential")
 
 
 update_control(source_package_cb=drop_build_essential)
