@@ -3,12 +3,16 @@ import os
 import subprocess
 import sys
 
+from lintian_brush.watch import WatchFile, Watch
+
+
 if os.path.exists('debian/watch'):
     # Nothing to do here..
     sys.exit(0)
 
 watch_contents = None
 site = None
+wf = WatchFile()
 if os.path.exists('setup.py'):
     (project, version) = subprocess.check_output(
         ['python3', 'setup.py', '--name', '--version']).splitlines()
@@ -16,17 +20,19 @@ if os.path.exists('setup.py'):
     # https://pypi.python.org/simple/<name>
     # TODO(jelmer): download watch file from
     # http://pypi.debian.net/<project>/watch
-    watch_contents = r"""version=3
-opts=uversionmangle=s/(rc|a|b|c)/~$1/,pgpsigurlmangle=s/$/.asc/ \
-https://pypi.debian.net/%(project)s/%(project)s-(.+)\.(?:zip|tgz|tbz|txz|(?:tar\.(?:gz|bz2|xz)))
-""" % {"project": project.decode()}
+    url = (r'https://pypi.debian.net/%(project)s/%(project)'
+           r's-(.+)\.(?:zip|tgz|tbz|txz|(?:tar\.(?:gz|bz2|xz)))' % {
+            'project': project.decode()})
+    w = Watch(url, opts=[
+        'uversionmangle=s/(rc|a|b|c)/~$1/', 'pgpsigurlmangle=s/$/.asc/'])
+    wf.entries.append(w)
     site = "pypi"
 
-if not watch_contents:
+if not wf.entries:
     sys.exit(0)
 
 with open('debian/watch', 'w') as f:
-    f.write(watch_contents)
+    wf.dump(f)
 
 print("Add debian/watch file, using %s." % site)
 print("Certainty: possible")
