@@ -31,8 +31,8 @@ new_debhelper_compat_version = {
 
 
 if check_cdbs():
-    # cdbs doesn't appear to support debheler 12 just yet..
-    new_debhelper_compat_version = min(new_debhelper_compat_version, 11)
+    # cdbs doesn't appear to support debhelper 11 or 12 just yet..
+    new_debhelper_compat_version = min(new_debhelper_compat_version, 10)
 
 
 if os.path.exists('debian/compat'):
@@ -128,25 +128,47 @@ def update_line(line, orig, new, description):
     return newline
 
 
+def update_line_drop_argument(target, line, command, argument, description):
+    if (line.startswith(command + b' ') or
+            (target == (b'override_' + command) and
+             line.startswith(b'$(overridden_command)'))) and argument in line:
+        line = dh_invoke_drop_argument(line, argument)
+        subitems.add(description)
+        return line, True
+    return line, False
+
+
 def upgrade_to_debhelper_12():
 
-    def cb(line):
+    def cb(line, target):
         line = update_line(
             line, b'dh_clean -k', b'dh_prep',
             'debian/rules: Replace dh_clean -k with dh_prep.')
+        # TODO(jelmer): Also make sure that any extra arguments to
+        # e.g. dh_auto_build get upgraded. E.g.
+        # this works with disutils but not pybuild:
+        # dh_auto_build -- --executable=/usr/bin/python
+        # TODO(jelmer): Also add a dependency on dh-python
         line = update_line(
             line, b'--buildsystem=python_distutils', b'--buildsystem=pybuild',
             'Replace python_distutils buildsystem with pybuild.')
-        if line.startswith(b'dh_install ') and b'--list-missing' in line:
-            line = dh_invoke_drop_argument(line, b'--list-missing')
-            subitems.add(
-                'debian/rules: Call dh_missing rather than using dh_install '
-                '--list-missing.')
-        if line.startswith(b'dh_install ') and b'--fail-missing' in line:
-            line = dh_invoke_drop_argument(line, b'--fail-missing')
-            subitems.add(
-                'debian/rules: Call dh_missing rather than using dh_install '
-                '--list-missing.')
+        line = update_line(
+            line, b'-O--buildsystem=python_distutils',
+            b'-O--buildsystem=pybuild',
+            'Replace python_distutils buildsystem with pybuild.')
+        if line.startswith(b'dh ') or line.startswith(b'dh_installinit'):
+            line = update_line(
+                line, b'--no-restart-on-upgrade',
+                b'--no-stop-on-upgrade',
+                'Replace --no-restart-on-upgrade with --no-stop-on-upgrade.')
+        line, changed = update_line_drop_argument(
+            target, line, b'dh_install', b'--list-missing',
+            'debian/rules: Call dh_missing rather than using dh_install '
+            '--list-missing.')
+        line, changed = update_line_drop_argument(
+            target, line, b'dh_install', b'--fail-missing',
+            'debian/rules: Move --fail-missing argument to dh_missing.')
+        if changed:
             return [line, b'dh_missing --fail-missing']
         return line
 
@@ -155,7 +177,7 @@ def upgrade_to_debhelper_12():
 
 def upgrade_to_debhelper_11():
 
-    def cb(line):
+    def cb(line, target):
         line = dh_invoke_drop_with(line, b'systemd')
         if line.startswith(b'dh_systemd_enable'):
             line = update_line(
@@ -165,6 +187,20 @@ def upgrade_to_debhelper_11():
         return line
 
     update_rules(cb)
+    for name in os.listdir('debian'):
+        parts = name.split('.')
+        if len(parts) < 2 or parts[-1] != 'upstart':
+            continue
+        if len(parts) == 3:
+            package = parts[0]
+            service = parts[1]
+        elif len(parts) == 2:
+            package = service = parts[0]
+        os.unlink(os.path.join('debian', name))
+        subitems.add('Drop obsolete upstart file %s.' % name)
+        with open('debian/%s.maintscript' % package, 'a') as f:
+            f.write('rm_conffile /etc/init/%s.conf %s\n' % (
+                service, os.environ['CURRENT_VERSION']))
 
 
 upgrade_to_debhelper = {
