@@ -46,7 +46,7 @@ from breezy.transform import revert
 from debian.deb822 import Deb822
 
 
-__version__ = (0, 23)
+__version__ = (0, 26)
 version_string = '.'.join(map(str, __version__))
 SUPPORTED_CERTAINTIES = ['certain', 'possible', None]
 DEFAULT_MINIMUM_CERTAINTY = 'certain'
@@ -683,3 +683,7 @@ def run_lintian_fixers(local_tree, fixers, update_changelog=True,
                          fixer.name, time.time() - start)
                 ret.append((result, summary))
     return ret, failed_fixers
+
+
+def certainty_to_confidence(certainty):
+    return SUPPORTED_CERTAINTIES.index(certainty)
