@@ -19,6 +19,7 @@
 
 import os
 import re
+import sys
 
 from debian.changelog import (
     Changelog,
@@ -35,20 +36,26 @@ from lintian_brush import (
     Fixer,
     FixerFailed,
     FixerResult,
-    GeneratedControlFile,
+    FixerScriptFailed,
     NoChanges,
     NotDebianPackage,
     PendingChanges,
+    PythonScriptFixer,
+    ScriptFixer,
+    UnsupportedCertainty,
     available_lintian_fixers,
+    check_clean_tree,
     certainty_sufficient,
     get_committer,
     increment_version,
     only_changes_last_changelog_block,
+    parse_script_fixer_output,
     run_lintian_fixer,
     run_lintian_fixers,
     version_string,
     )
 
+
 CHANGELOG_FILE = ('debian/changelog', """\
 blah (0.1) UNRELEASED; urgency=medium
 
@@ -83,6 +90,70 @@ Lintian-Tags: i-fix-another-tag, no-extension
                  for fixer in available_lintian_fixers('fixers')])
 
 
+class CheckCleanTreeTests(TestCaseWithTransport):
+
+    def make_test_tree(self, format=None):
+        tree = self.make_branch_and_tree('.', format=format)
+        self.build_tree_contents([
+            ('debian/', ),
+            ('debian/control', """\
+Source: blah
+Vcs-Git: https://example.com/blah
+Testsuite: autopkgtest
+
+Binary: blah
+Arch: all
+
+"""),
+            CHANGELOG_FILE])
+        tree.add(['debian', 'debian/changelog', 'debian/control'])
+        tree.commit('Initial thingy.')
+        return tree
+
+    def test_pending_changes(self):
+        tree = self.make_test_tree()
+        self.build_tree_contents([('debian/changelog', 'blah')])
+        with tree.lock_write():
+            self.assertRaises(
+                PendingChanges, check_clean_tree, tree)
+
+    def test_pending_changes_bzr_empty_dir(self):
+        # See https://bugs.debian.org/914038
+        tree = self.make_test_tree(format='bzr')
+        self.build_tree_contents([('debian/upstream/', )])
+        with tree.lock_write():
+            self.assertRaises(
+                PendingChanges, check_clean_tree, tree)
+
+    def test_pending_changes_git_empty_dir(self):
+        # See https://bugs.debian.org/914038
+        tree = self.make_test_tree(format='git')
+        self.build_tree_contents([('debian/upstream/', )])
+        with tree.lock_write():
+            check_clean_tree(tree)
+
+    def test_pending_changes_git_dir_with_ignored(self):
+        # See https://bugs.debian.org/914038
+        tree = self.make_test_tree(format='git')
+        self.build_tree_contents([
+            ('debian/upstream/', ),
+            ('debian/upstream/blah', ''),
+            ('.gitignore', 'blah\n'),
+            ])
+        tree.add('.gitignore')
+        tree.commit('add gitignore')
+        with tree.lock_write():
+            check_clean_tree(tree)
+
+    def test_extra(self):
+        tree = self.make_test_tree()
+        self.build_tree_contents([('debian/foo', 'blah')])
+        with tree.lock_write():
+            self.assertRaises(
+                PendingChanges, check_clean_tree,
+                tree)
+
+
 class DummyFixer(Fixer):
 
     def run(self, basedir, current_version, compat_release, minimum_certainty,
@@ -124,72 +195,6 @@ Arch: all
         tree.commit('Initial thingy.')
         return tree
 
-    def test_pending_changes(self):
-        tree = self.make_test_tree()
-        self.build_tree_contents([('debian/changelog', 'blah')])
-        with tree.lock_write():
-            self.assertRaises(
-                PendingChanges, run_lintian_fixer,
-                tree, DummyFixer('dummy', 'some-tag'),
-                update_changelog=False)
-
-    def test_pending_changes_bzr_empty_dir(self):
-        # See https://bugs.debian.org/914038
-        tree = self.make_test_tree(format='bzr')
-        self.build_tree_contents([('debian/upstream/', )])
-        with tree.lock_write():
-            self.assertRaises(
-                PendingChanges, run_lintian_fixer,
-                tree, DummyFixer('dummy', 'some-tag'),
-                update_changelog=False)
-
-    def test_pending_changes_git_empty_dir(self):
-        # See https://bugs.debian.org/914038
-        tree = self.make_test_tree(format='git')
-        self.build_tree_contents([('debian/upstream/', )])
-        with tree.lock_write():
-            result, summary = run_lintian_fixer(
-                tree, DummyFixer('dummy', 'some-tag'),
-                update_changelog=False)
-        self.assertEqual(summary, "Fixed some tag.")
-        self.assertEqual(['some-tag'], result.fixed_lintian_tags)
-        self.assertEqual('certain', result.certainty)
-        self.assertEqual(2, tree.branch.revno())
-        self.assertEqual(
-                tree.get_file_lines('debian/control')[-1],
-                b"a new line\n")
-
-    def test_pending_changes_git_dir_with_ignored(self):
-        # See https://bugs.debian.org/914038
-        tree = self.make_test_tree(format='git')
-        self.build_tree_contents([
-            ('debian/upstream/', ),
-            ('debian/upstream/blah', ''),
-            ('.gitignore', 'blah\n'),
-            ])
-        tree.add('.gitignore')
-        tree.commit('add gitignore')
-        with tree.lock_write():
-            result, summary = run_lintian_fixer(
-                tree, DummyFixer('dummy', 'some-tag'),
-                update_changelog=False)
-        self.assertEqual(summary, "Fixed some tag.")
-        self.assertEqual(['some-tag'], result.fixed_lintian_tags)
-        self.assertEqual('certain', result.certainty)
-        self.assertEqual(3, tree.branch.revno())
-        self.assertEqual(
-                tree.get_file_lines('debian/control')[-1],
-                b"a new line\n")
-
-    def test_extra(self):
-        tree = self.make_test_tree()
-        self.build_tree_contents([('debian/foo', 'blah')])
-        with tree.lock_write():
-            self.assertRaises(
-                PendingChanges, run_lintian_fixer,
-                tree, DummyFixer('dummy', 'some-tag'),
-                update_changelog=False)
-
     def test_not_debian_tree(self):
         tree = self.make_test_tree()
         tree.remove('debian/changelog')
@@ -391,19 +396,6 @@ Arch: all
                 self.tree.get_file_lines('debian/control')[-1],
                 b"a new line\n")
 
-    def test_generated_control_file(self):
-        with self.tree.lock_write():
-            self.build_tree_contents([
-                ('debian/control.in', """\
-Source: blah
-""")])
-            self.tree.add(['debian/control.in'])
-            self.tree.commit('Add control.in')
-            self.assertRaises(
-                GeneratedControlFile, run_lintian_fixers,
-                self.tree, [DummyFixer('dummy', 'some-tag')],
-                update_changelog=False)
-
 
 class HonorsVcsCommitter(TestCaseWithTransport):
 
@@ -687,3 +679,85 @@ class CertaintySufficientTests(TestCase):
 
     def test_insufficient(self):
         self.assertFalse(certainty_sufficient('possible', 'certain'))
+
+
+class ParseScriptFixerOutputTests(TestCase):
+
+    def test_simple(self):
+        self.assertEqual(
+            FixerResult('Do bla', ['tag-a'], 'certain'),
+            parse_script_fixer_output("""\
+Do bla
+Fixed-Lintian-Tags: tag-a
+Certainty: certain
+"""))
+
+    def test_unknown_certainty(self):
+        self.assertRaises(
+            UnsupportedCertainty,
+            parse_script_fixer_output, """\
+Do bla
+Fixed-Lintian-Tags: tag-a
+Certainty: blah
+""")
+
+    def test_default_certainty(self):
+        self.assertEqual(
+            FixerResult('Do bla', ['tag-a'], None),
+            parse_script_fixer_output("""\
+Do bla
+Fixed-Lintian-Tags: tag-a
+"""))
+
+
+class BaseScriptFixerTests(object):
+
+    script_fixer_cls = None
+
+    def create_fixer(self, code):
+        self.build_tree_contents([
+            ('script.py',
+             "#!" + sys.executable + "\n" + code)])
+        os.chmod('script.py', 0o755)
+        fixer = self.script_fixer_cls(
+            'fixer', ['a-tag'], os.path.abspath('script.py'))
+        self.assertEqual(os.path.abspath('script.py'), fixer.script_path)
+        return fixer
+
+    def test_noop(self):
+        fixer = self.create_fixer("print('I did not do anything')\n")
+        result = fixer.run(self.test_dir, '0.1', 'buster')
+        self.assertIsInstance(result, FixerResult)
+        self.assertEqual(result.description, 'I did not do anything')
+
+    def test_chdir(self):
+        fixer = self.create_fixer("import os; print(os.getcwd())\n")
+        os.mkdir('subdir')
+        os.chdir('subdir')
+        result = fixer.run(self.test_dir, '0.1', 'buster')
+        self.assertIsInstance(result, FixerResult)
+        self.assertEqual(result.description, self.test_dir)
+
+    def test_exception(self):
+        fixer = self.create_fixer("""\
+def foo():
+    raise Exception('oops')
+foo()
+""")
+        e = self.assertRaises(
+            FixerScriptFailed, fixer.run, self.test_dir, '0.1', 'buster')
+        self.assertEqual(e.path, fixer.script_path)
+        self.assertEqual(e.returncode, 1)
+        self.assertEqual(
+            e.errors.splitlines()[-2:],
+            ["    raise Exception('oops')", 'Exception: oops'])
+
+
+class ScriptFixerTests(BaseScriptFixerTests, TestCaseWithTransport):
+
+    script_fixer_cls = ScriptFixer
+
+
+class PythonScriptFixerTests(BaseScriptFixerTests, TestCaseWithTransport):
+
+    script_fixer_cls = PythonScriptFixer
