@@ -27,6 +27,7 @@ from lintian_brush.upstream_metadata import (
     guess_repo_from_url,
     guess_from_package_json,
     guess_from_debian_watch,
+    guess_from_r_description,
     )
 
 
@@ -102,6 +103,57 @@ class GuessFromPackageJsonTests(TestCaseWithTransport):
             list(guess_from_package_json('package.json', False)))
 
 
+class GuessFromRDescriptionTests(TestCaseWithTransport):
+
+    def test_read(self):
+        self.build_tree_contents([('DESCRIPTION', """\
+Package: crul
+Title: HTTP Client
+Description: A simple HTTP client, with tools for making HTTP requests,
+    and mocking HTTP requests. The package is built on R6, and takes
+    inspiration from Ruby's 'faraday' gem (<https://rubygems.org/gems/faraday>)
+    The package name is a play on curl, the widely used command line tool
+    for HTTP, and this package is built on top of the R package 'curl', an
+    interface to 'libcurl' (<https://curl.haxx.se/libcurl>).
+Version: 0.8.4
+License: MIT + file LICENSE
+Authors@R: c(
+    person("Scott", "Chamberlain", role = c("aut", "cre"),
+    email = "myrmecocystus@gmail.com",
+    comment = c(ORCID = "0000-0003-1444-9135"))
+    )
+URL: https://github.com/ropensci/crul (devel)
+        https://ropenscilabs.github.io/http-testing-book/ (user manual)
+        https://www.example.com/crul (homepage)
+BugReports: https://github.com/ropensci/crul/issues
+Encoding: UTF-8
+Language: en-US
+Imports: curl (>= 3.3), R6 (>= 2.2.0), urltools (>= 1.6.0), httpcode
+        (>= 0.2.0), jsonlite, mime
+Suggests: testthat, fauxpas (>= 0.1.0), webmockr (>= 0.1.0), knitr
+VignetteBuilder: knitr
+RoxygenNote: 6.1.1
+X-schema.org-applicationCategory: Web
+X-schema.org-keywords: http, https, API, web-services, curl, download,
+        libcurl, async, mocking, caching
+X-schema.org-isPartOf: https://ropensci.org
+NeedsCompilation: no
+Packaged: 2019-08-02 19:58:21 UTC; sckott
+Author: Scott Chamberlain [aut, cre] (<https://orcid.org/0000-0003-1444-9135>)
+Maintainer: Scott Chamberlain <myrmecocystus@gmail.com>
+Repository: CRAN
+Date/Publication: 2019-08-02 20:30:02 UTC
+""")])
+        ret = guess_from_r_description('DESCRIPTION', True)
+        self.assertEqual(list(ret), [
+            ('Name', 'crul', 'certain'),
+            ('Archive', 'CRAN', 'certain'),
+            ('Bug-Database', 'https://github.com/ropensci/crul/issues',
+                'certain'),
+            ('Repository', 'https://github.com/ropensci/crul', 'certain'),
+            ('Homepage', 'https://www.example.com/crul', 'certain')])
+
+
 class GuessRepoFromUrlTests(TestCase):
 
     def test_github(self):
