@@ -22,7 +22,7 @@ import os
 import re
 import subprocess
 import tempfile
-from urllib.parse import urlparse
+from urllib.parse import urlparse, urlunparse
 from warnings import warn
 from lintian_brush import USER_AGENT
 from lintian_brush.vcs import (
@@ -33,8 +33,8 @@ from urllib.request import urlopen, Request
 
 
 KNOWN_HOSTING_SITES = [
-    'code.launchpad.net', 'github.com', 'gitlab.com', 'launchpad.net',
-    'salsa.debian.org']
+    'code.launchpad.net', 'github.com', 'launchpad.net']
+KNOWN_GITLAB_SITES = ['gitlab.com', 'salsa.debian.org']
 
 
 def get_sf_metadata(project):
@@ -54,6 +54,14 @@ def guess_repo_from_url(url):
     if parsed_url.netloc == 'launchpad.net':
         return 'https://code.launchpad.net/%s' % (
             parsed_url.path.strip('/').split('/')[0])
+    if parsed_url.netloc in KNOWN_GITLAB_SITES:
+        if parsed_url.path.strip('/').count('/') < 1:
+            return None
+        parts = parsed_url.path.split('/')
+        if 'tags' in parts:
+            parts = parts[:parts.index('tags')]
+        return urlunparse(
+            parsed_url._replace(path='/'.join(parts), query=''))
     if parsed_url.netloc in KNOWN_HOSTING_SITES:
         return url
     return None
@@ -114,6 +122,7 @@ def guess_from_debian_watch(path, trust_package):
             m = re.match('https?://sf.net/([^/]+)', w.url)
             if m:
                 yield "Archive", "SourceForge", "certain"
+                yield "X-SourceForge-Project", m.group(1), "certain"
                 # TODO(jelmer): Yield sourceforge project name later
                 # so something later can call get_sf_metadata ?
 
@@ -184,7 +193,8 @@ def guess_from_package_xml(path, trust_package):
     tree = ET.parse(path)
     root = tree.getroot()
     assert root.tag in (
-        'package', '{http://pear.php.net/dtd/package-2.0}package'
+        'package', '{http://pear.php.net/dtd/package-2.0}package',
+        '{http://pear.php.net/dtd/package-2.1}package',
         ), 'root tag is %r' % root.tag
     name_tag = root.find('name')
     if name_tag is not None:
@@ -233,7 +243,7 @@ def guess_from_debian_copyright(path, trust_package):
         )
     with open(path, 'r') as f:
         try:
-            copyright = Copyright(f)
+            copyright = Copyright(f, strict=False)
         except NotMachineReadableError:
             header = None
         except MachineReadableFormatError as e:
@@ -262,13 +272,16 @@ def guess_from_debian_copyright(path, trust_package):
 
 
 def guess_from_readme(path, trust_package):
+    import shlex
     try:
         with open(path, 'rb') as f:
             for line in f:
                 line = line.decode('utf-8', 'replace')
                 if line.strip().startswith('git clone'):
                     line = line.strip()
-                    url = line.split()[2]
+                    argv = shlex.split(line)
+                    args = [arg for arg in argv[2:] if not arg.startswith('-')]
+                    url = args[0]
                     yield ('Repository', sanitize_vcs_url(url), 'possible')
     except IsADirectoryError:
         pass
@@ -372,23 +385,26 @@ def guess_from_doap(path, trust_package):
 
 
 def guess_from_configure(path, trust_package=False):
-    with open(path, 'r') as f:
+    with open(path, 'rb') as f:
         for line in f:
-            if '=' not in line:
+            if b'=' not in line:
                 continue
-            (key, value) = line.strip().split('=', 1)
-            if ' ' in key:
+            (key, value) = line.strip().split(b'=', 1)
+            if b' ' in key:
                 continue
-            if '$' in value:
+            if b'$' in value:
                 continue
-            if value.startswith("'") and value.endswith("'"):
+            value = value.strip()
+            if value.startswith(b"'") and value.endswith(b"'"):
                 value = value[1:-1]
-            if key == 'PACKAGE_NAME':
-                yield 'Name', value, 'certain'
-            elif key == 'PACKAGE_BUGREPORT':
-                yield 'Bug-Submit', value, 'certain'
-            elif key == 'PACKAGE_URL':
-                yield 'Homepage', value, 'certain'
+            if not value:
+                continue
+            if key == b'PACKAGE_NAME':
+                yield 'Name', value.decode(), 'certain'
+            elif key == b'PACKAGE_BUGREPORT':
+                yield 'Bug-Submit', value.decode(), 'certain'
+            elif key == b'PACKAGE_URL':
+                yield 'Homepage', value.decode(), 'certain'
 
 
 def guess_from_r_description(path, trust_package=False):
@@ -402,16 +418,33 @@ def guess_from_r_description(path, trust_package=False):
         if 'BugReports' in description:
             yield 'Bug-Database', description['BugReports'], 'certain'
         if 'URL' in description:
-            urls = [url.strip() for url in description['URL'].split(',')]
+            entries = [entry.strip()
+                       for entry in re.split('[\n,]', description['URL'])]
+            urls = []
+            for entry in entries:
+                m = re.match('([^ ]+) \\((.*)\\)', entry)
+                if m:
+                    url = m.group(1)
+                    label = m.group(2)
+                else:
+                    url = entry
+                    label = None
+                urls.append((label, url))
             if len(urls) == 1:
-                yield 'Homepage', urls[0], 'possible'
-            for url in urls:
-                repo_url = guess_repo_from_url(url)
-                if repo_url:
-                    yield 'Repository', repo_url, 'certain'
+                yield 'Homepage', urls[0][1], 'possible'
+            for label, url in urls:
+                if label and label.lower() in ('devel', 'repository'):
+                    yield 'Repository', url, 'certain'
+                elif label and label.lower() in ('homepage', ):
+                    yield 'Homepage', url, 'certain'
+                else:
+                    repo_url = guess_repo_from_url(url)
+                    if repo_url:
+                        yield 'Repository', repo_url, 'certain'
 
 
-def guess_upstream_metadata_items(path, trust_package=False):
+def guess_upstream_metadata_items(path, trust_package=False,
+                                  minimum_certainty=None):
     """Guess upstream metadata items, in no particular order.
 
     Args:
@@ -454,6 +487,8 @@ def guess_upstream_metadata_items(path, trust_package=False):
             continue
         for key, value, certainty in guesser(
                 abspath, trust_package=trust_package):
+            if certainty == 'possible' and minimum_certainty == 'certain':
+                continue
             yield key, value, certainty
 
     # TODO(jelmer): validate Repository by querying it somehow?
